local MODE_EPGP = "epgp"
local MODE_ROLL = "roll"
local currentMode = MODE_ROLL

local origUpdateFrame = LootHistoryFrame_UpdatePlayerFrame

local bufferedEPGPs = {}

local function GetEPGPText(itemIdx, playerIdx)

    if (not bufferedEPGPs[itemIdx]) then
        bufferedEPGPs[itemIdx] = {}
    end

    if (not bufferedEPGPs[itemIdx][playerIdx]) then
        bufferedEPGPs[itemIdx][playerIdx] = {}

        local name = C_LootHistory.GetPlayerInfo(itemIdx, playerIdx);
        local ep,gp = EPGP:GetEPGP(name)

        bufferedEPGPs[itemIdx][playerIdx].EPGP = (ep/gp)
        bufferedEPGPs[itemIdx][playerIdx].HasMinEP = (ep > EPGP:GetMinEP())
    end

    local text = string.format(" %.2f",bufferedEPGPs[itemIdx][playerIdx].EPGP)
    if (not bufferedEPGPs[itemIdx][playerIdx].HasMinEP) then
        text = '|cff555555'..text..'|r'
    end

    return text
end

function LootHistoryFrame_UpdatePlayerFrame(self, playerFrame)
    local origResult = origUpdateFrame(self,playerFrame)
    if (playerFrame.playerIdx) then
        if (currentMode == MODE_EPGP) then
            if (playerFrame.RollText:GetText()) then
                playerFrame.RollText:SetText(GetEPGPText(playerFrame.itemIdx, playerFrame.playerIdx))
                playerFrame.RollText:SetSize(0,16)
            end
        else
            -- reset to default options
            playerFrame.RollText:SetSize(24,16)
        end
    end

    return origResult
end

local function UpdateBtnTexture(btn, mode)
    if (mode == MODE_EPGP) then
        btn:SetNormalTexture("Interface\\GossipFrame\\VendorGossipIcon")
    else
        btn:SetNormalTexture("Interface\\Buttons\\UI-GroupLoot-Dice-Up")
    end
end

local function ToggleCurrentMode(self)
    if (currentMode == MODE_ROLL) then
        currentMode = MODE_EPGP
    else
        currentMode = MODE_ROLL
    end

    UpdateBtnTexture(self, currentMode)
    LootHistoryFrame_FullUpdate(LootHistoryFrame)
end


local function BuildToggleBtn(frame)

    local btn = CreateFrame("Button","ToggleLootModeBtn",frame)
    btn:SetPoint("TOPRIGHT",frame,"TOPLEFT",2,-8)
    btn:SetSize(16, 16)
    UpdateBtnTexture(btn, currentMode)
    btn:SetScript('OnClick', ToggleCurrentMode)

    return btn
end

LootHistoryFrame:HookScript("OnShow", function(self)
    if (not self.ToggleLootModeBtn) then
        self.ToggleLootModeBtn = BuildToggleBtn(self.CloseButton)
    end
end)
